@@ -9,8 +9,7 @@
 #define _NCPLIB_H
 
 #include <linux/types.h>
-#include <linux/ncp.h>
-#include <linux/ncp_fs.h>
+#include "ncp.h"
 #include <linux/ipx.h>
 #include <sys/param.h>
 #include <stdio.h>
@@ -33,23 +32,21 @@ typedef __u32 dword;
 #define BSET(buf,pos,val) (BVAL(buf,pos) = (val))
 
 static inline word
-WVAL_HL(__u8 * buf, int pos)
+ WVAL_HL(__u8 * buf, int pos)
 {
 	return PVAL(buf, pos) << 8 | PVAL(buf, pos + 1);
 }
 static inline dword
-DVAL_HL(__u8 * buf, int pos)
+ DVAL_HL(__u8 * buf, int pos)
 {
 	return WVAL_HL(buf, pos) << 16 | WVAL_HL(buf, pos + 2);
 }
-static inline void
-WSET_HL(__u8 * buf, int pos, word val)
+static inline void WSET_HL(__u8 * buf, int pos, word val)
 {
 	BSET(buf, pos, val >> 8);
 	BSET(buf, pos + 1, val & 0xff);
 }
-static inline void
-DSET_HL(__u8 * buf, int pos, dword val)
+static inline void DSET_HL(__u8 * buf, int pos, dword val)
 {
 	WSET_HL(buf, pos, val >> 16);
 	WSET_HL(buf, pos + 2, val & 0xffff);
@@ -61,22 +58,20 @@ DSET_HL(__u8 * buf, int pos, dword val)
 #if defined(__i386__)
 
 static inline word
-WVAL_LH(__u8 * buf, int pos)
+ WVAL_LH(__u8 * buf, int pos)
 {
 	return *((word *) (buf + pos));
 }
 static inline dword
-DVAL_LH(__u8 * buf, int pos)
+ DVAL_LH(__u8 * buf, int pos)
 {
 	return *((dword *) (buf + pos));
 }
-static inline void
-WSET_LH(__u8 * buf, int pos, word val)
+static inline void WSET_LH(__u8 * buf, int pos, word val)
 {
 	*((word *) (buf + pos)) = val;
 }
-static inline void
-DSET_LH(__u8 * buf, int pos, dword val)
+static inline void DSET_LH(__u8 * buf, int pos, dword val)
 {
 	*((dword *) (buf + pos)) = val;
 }
@@ -84,23 +79,21 @@ DSET_LH(__u8 * buf, int pos, dword val)
 #else
 
 static inline word
-WVAL_LH(__u8 * buf, int pos)
+ WVAL_LH(__u8 * buf, int pos)
 {
 	return PVAL(buf, pos) | PVAL(buf, pos + 1) << 8;
 }
 static inline dword
-DVAL_LH(__u8 * buf, int pos)
+ DVAL_LH(__u8 * buf, int pos)
 {
 	return WVAL_LH(buf, pos) | WVAL_LH(buf, pos + 2) << 16;
 }
-static inline void
-WSET_LH(__u8 * buf, int pos, word val)
+static inline void WSET_LH(__u8 * buf, int pos, word val)
 {
 	BSET(buf, pos, val & 0xff);
 	BSET(buf, pos + 1, val >> 8);
 }
-static inline void
-DSET_LH(__u8 * buf, int pos, dword val)
+static inline void DSET_LH(__u8 * buf, int pos, dword val)
 {
 	WSET_LH(buf, pos, val & 0xffff);
 	WSET_LH(buf, pos + 2, val >> 16);
@@ -114,15 +107,13 @@ DSET_LH(__u8 * buf, int pos, dword val)
 void
  str_upper(char *name);
 
-enum connect_state
-{
+enum connect_state {
 	NOT_CONNECTED = 0,
 	CONN_PERMANENT,
 	CONN_TEMPORARY
 };
 
-struct ncp_conn
-{
+struct ncp_conn {
 
 	enum connect_state is_connected;
 
@@ -155,8 +146,7 @@ struct ncp_conn
 	char packet[NCP_PACKET_SIZE];
 };
 
-struct ncp_conn_spec
-{
+struct ncp_conn_spec {
 	char server[NCP_BINDERY_NAME_LEN];
 	char user[NCP_BINDERY_NAME_LEN];
 	uid_t uid;
@@ -164,14 +154,12 @@ struct ncp_conn_spec
 	char password[NCP_BINDERY_NAME_LEN];
 };
 
-struct ncp_search_seq
-{
+struct ncp_search_seq {
 	struct nw_search_sequence s;
 	int namespace;
 };
 
-struct ncp_property_info
-{
+struct ncp_property_info {
 	__u8 property_name[16];
 	__u8 property_flags;
 	__u8 property_security;
@@ -225,8 +213,7 @@ long
 /* like getmntent, get_ncp_conn_ent scans /etc/mtab for usable
    connections */
 
-struct ncp_conn_ent
-{
+struct ncp_conn_ent {
 	char server[NCP_BINDERY_NAME_LEN];
 	char user[NCP_BINDERY_NAME_LEN];
 	uid_t uid;
@@ -254,8 +241,7 @@ long
 long
  ncp_set_file_server_time(struct ncp_conn *conn, time_t * source);
 
-struct ncp_file_server_info
-{
+struct ncp_file_server_info {
 	__u8 ServerName[48] __attribute__((packed));
 	__u8 FileServiceVersion __attribute__((packed));
 	__u8 FileServiceSubVersion __attribute__((packed));
@@ -316,7 +302,7 @@ long
 			     struct ncp_bindery_object *target);
 long
  ncp_scan_bindery_object(struct ncp_conn *conn,
-			 __u32 last_id, __u16 object_type, char *search_string,
+		   __u32 last_id, __u16 object_type, char *search_string,
 			 struct ncp_bindery_object *target);
 long
  ncp_create_bindery_object(struct ncp_conn *conn,
@@ -335,15 +321,13 @@ long
 			    const char *object_name,
 			    __u8 security);
 
-struct ncp_station_addr
-{
+struct ncp_station_addr {
 	__u32 NetWork __attribute__((packed));
 	__u8 Node[6] __attribute__((packed));
 	__u16 Socket __attribute__((packed));
 };
 
-struct ncp_prop_login_control
-{
+struct ncp_prop_login_control {
 	__u8 AccountExpireDate[3] __attribute__((packed));
 	__u8 Disabled __attribute__((packed));
 	__u8 PasswordExpireDate[3] __attribute__((packed));
@@ -606,8 +590,8 @@ long
 
 long
  ncp_ren_or_mov_file_or_subdir(struct ncp_conn *conn,
-			       struct nw_info_struct *old_dir, char *old_name,
-			       struct nw_info_struct *new_dir, char *new_name);
+			  struct nw_info_struct *old_dir, char *old_name,
+			 struct nw_info_struct *new_dir, char *new_name);
 
 long
  ncp_create_queue_job_and_file(struct ncp_conn *conn,
@@ -660,8 +644,7 @@ long
 			      struct nw_info_struct *file,
 			      __u16 * target);
 
-struct ncp_trustee_struct
-{
+struct ncp_trustee_struct {
 	__u32 object_id;
 	__u16 rights;
 };
