@@ -5,8 +5,7 @@
 #include <sys/socket.h>
 #include <errno.h>
 
-int
-main(int argc, char **argv)
+int main(int argc, char **argv)
 {
 	struct sockaddr_ipx sipx;
 	int s;
@@ -15,8 +14,7 @@ main(int argc, char **argv)
 	int len;
 
 	s = socket(AF_IPX, SOCK_DGRAM, AF_IPX);
-	if (s < 0)
-	{
+	if (s < 0) {
 		perror("IPX: socket: ");
 		exit(-1);
 	}
@@ -26,16 +24,14 @@ main(int argc, char **argv)
 	sipx.sipx_type = 17;
 	len = sizeof(sipx);
 	result = bind(s, (struct sockaddr *) &sipx, sizeof(sipx));
-	if (result < 0)
-	{
+	if (result < 0) {
 		perror("IPX: bind: ");
 		exit(-1);
 	}
 	msg[0] = '\0';
 	result = recvfrom(s, msg, sizeof(msg), 0, (struct sockaddr *) &sipx,
 			  &len);
-	if (result < 0)
-	{
+	if (result < 0) {
 		perror("IPX: recvfrom: ");
 	}
 	printf("From %08lX:%02X%02X%02X%02X%02X%02X:%04X\n",
