@@ -9,8 +9,7 @@
 #include <sys/socket.h>
 #include <errno.h>
 
-int
-main(int argc, char **argv)
+int main(int argc, char **argv)
 {
 	struct sockaddr_ipx sipx;
 	int s;
@@ -19,8 +18,7 @@ main(int argc, char **argv)
 	int len = sizeof(sipx);
 
 	s = socket(AF_IPX, SOCK_DGRAM, AF_IPX);
-	if (s < 0)
-	{
+	if (s < 0) {
 		perror("IPX: socket: ");
 		exit(-1);
 	}
@@ -30,8 +28,7 @@ main(int argc, char **argv)
 	sipx.sipx_type = 17;
 
 	result = bind(s, (struct sockaddr *) &sipx, sizeof(sipx));
-	if (result < 0)
-	{
+	if (result < 0) {
 		perror("IPX: bind: ");
 		exit(-1);
 	}
@@ -39,8 +36,7 @@ main(int argc, char **argv)
 	sipx.sipx_port = htons(0x5000);
 	result = sendto(s, msg, sizeof(msg), 0, (struct sockaddr *) &sipx,
 			sizeof(sipx));
-	if (result < 0)
-	{
+	if (result < 0) {
 		perror("IPX: send: ");
 		exit(-1);
 	}
