@@ -21,8 +21,7 @@
 static struct ifreq id;
 static char *progname;
 
-void
-usage(void)
+void usage(void)
 {
 	fprintf(stderr, "Usage: %s add [-p] device frame_type [net_number]\n\
 Usage: %s del device frame_type\n\
@@ -31,12 +30,11 @@ Usage: %s check device frame_type\n", progname, progname, progname, progname);
 	exit(-1);
 }
 
-struct frame_type
-{
+struct frame_type {
 	char *ft_name;
 	unsigned char ft_val;
-}
-frame_types[] =
+} frame_types[] =
+
 {
 	{
 		"802.2", IPX_FRAME_8022
@@ -63,22 +61,19 @@ frame_types[] =
 
 #define NFTYPES	(sizeof(frame_types)/sizeof(struct frame_type))
 
-int
-lookup_frame_type(char *frame)
+int lookup_frame_type(char *frame)
 {
 	int j;
 
 	for (j = 0; (j < NFTYPES) &&
 	     (strcasecmp(frame_types[j].ft_name, frame));
-	     j++)
-		;
+	     j++);
 
 	if (j != NFTYPES)
 		return j;
 
 	fprintf(stderr, "%s: Frame type must be", progname);
-	for (j = 0; j < NFTYPES; j++)
-	{
+	for (j = 0; j < NFTYPES; j++) {
 		fprintf(stderr, "%s%s",
 			(j == NFTYPES - 1) ? " or " : " ",
 			frame_types[j].ft_name);
@@ -87,8 +82,7 @@ lookup_frame_type(char *frame)
 	return -1;
 }
 
-int
-ipx_add_interface(int argc, char **argv)
+int ipx_add_interface(int argc, char **argv)
 {
 	struct sockaddr_ipx *sipx = (struct sockaddr_ipx *) &id.ifr_addr;
 	int s;
@@ -101,24 +95,19 @@ ipx_add_interface(int argc, char **argv)
 	sipx->sipx_special = IPX_SPECIAL_NONE;
 	sipx->sipx_network = 0L;
 	sipx->sipx_type = IPX_FRAME_NONE;
-	while ((c = getopt(argc, argv, "p")) > 0)
-	{
-		switch (c)
-		{
+	while ((c = getopt(argc, argv, "p")) > 0) {
+		switch (c) {
 		case 'p':
 			sipx->sipx_special = IPX_PRIMARY;
 			break;
 		}
 	}
 
-	if (((i = (argc - optind)) < 2) || (i > 3))
-	{
+	if (((i = (argc - optind)) < 2) || (i > 3)) {
 		usage();
 	}
-	for (i = optind; i < argc; i++)
-	{
-		switch (i - optind)
-		{
+	for (i = optind; i < argc; i++) {
+		switch (i - optind) {
 		case 0:	/* Physical Device - Required */
 			strcpy(id.ifr_name, argv[i]);
 			break;
@@ -131,10 +120,9 @@ ipx_add_interface(int argc, char **argv)
 
 		case 2:	/* Network Number - Optional */
 			netnum = strtoul(argv[i], (char **) NULL, 16);
-			if (netnum == 0xffffffffL)
-			{
+			if (netnum == 0xffffffffL) {
 				fprintf(stderr,
-				   "%s: Inappropriate network number %08lX\n",
+					"%s: Inappropriate network number %08lX\n",
 					progname, netnum);
 				exit(-1);
 			}
@@ -144,13 +132,11 @@ ipx_add_interface(int argc, char **argv)
 	}
 
 	s = socket(AF_IPX, SOCK_DGRAM, AF_IPX);
-	if (s < 0)
-	{
+	if (s < 0) {
 		int old_errno = errno;
 		sprintf(errmsg, "%s: socket", progname);
 		perror(errmsg);
-		if (old_errno == -EINVAL)
-		{
+		if (old_errno == -EINVAL) {
 			fprintf(stderr, "Probably you have no IPX support in "
 				"your kernel\n");
 		}
@@ -159,8 +145,7 @@ ipx_add_interface(int argc, char **argv)
 	i = 0;
 	sipx->sipx_family = AF_IPX;
 	sipx->sipx_action = IPX_CRTITF;
-	do
-	{
+	do {
 		result = ioctl(s, SIOCSIFADDR, &id);
 		i++;
 	}
@@ -169,8 +154,7 @@ ipx_add_interface(int argc, char **argv)
 	if (result == 0)
 		exit(0);
 
-	switch (errno)
-	{
+	switch (errno) {
 	case EEXIST:
 		fprintf(stderr, "%s: Primary network already selected.\n",
 			progname);
@@ -208,8 +192,7 @@ ipx_add_interface(int argc, char **argv)
 	exit(-1);
 }
 
-int
-ipx_delall_interface(int argc, char **argv)
+int ipx_delall_interface(int argc, char **argv)
 {
 	struct sockaddr_ipx *sipx = (struct sockaddr_ipx *) &id.ifr_addr;
 	int s;
@@ -222,31 +205,26 @@ ipx_delall_interface(int argc, char **argv)
 	FILE *fp;
 
 	s = socket(AF_IPX, SOCK_DGRAM, AF_IPX);
-	if (s < 0)
-	{
+	if (s < 0) {
 		sprintf(errmsg, "%s: socket", progname);
 		perror(errmsg);
 		exit(-1);
 	}
 	fp = fopen("/proc/net/ipx_interface", "r");
-	if (fp == NULL)
-	{
+	if (fp == NULL) {
 		fprintf(stderr,
-			"%s: Unable to open \"/proc/net/ipx_interface.\"\n",
+		     "%s: Unable to open \"/proc/net/ipx_interface.\"\n",
 			progname);
 		exit(-1);
 	}
 	fgets(buffer, 80, fp);
 	while (fscanf(fp, "%s %s %s %s %s", buffer, buffer, buffer,
-		      device, frame_type) == 5)
-	{
+		      device, frame_type) == 5) {
 
 		sipx->sipx_network = 0L;
-		if (strcasecmp(device, "Internal") == 0)
-		{
+		if (strcasecmp(device, "Internal") == 0) {
 			sipx->sipx_special = IPX_INTERNAL;
-		} else
-		{
+		} else {
 			sipx->sipx_special = IPX_SPECIAL_NONE;
 			strcpy(id.ifr_name, device);
 			fti = lookup_frame_type(frame_type);
@@ -260,8 +238,7 @@ ipx_delall_interface(int argc, char **argv)
 		result = ioctl(s, SIOCSIFADDR, &id);
 		if (result == 0)
 			continue;
-		switch (errno)
-		{
+		switch (errno) {
 		case EPROTONOSUPPORT:
 			fprintf(stderr, "%s: Invalid frame type (%s).\n",
 				progname, frame_type);
@@ -284,8 +261,7 @@ ipx_delall_interface(int argc, char **argv)
 	exit(0);
 }
 
-int
-ipx_del_interface(int argc, char **argv)
+int ipx_del_interface(int argc, char **argv)
 {
 	struct sockaddr_ipx *sipx = (struct sockaddr_ipx *) &id.ifr_addr;
 	int s;
@@ -293,8 +269,7 @@ ipx_del_interface(int argc, char **argv)
 	char errmsg[80];
 	int fti;
 
-	if (argc != 3)
-	{
+	if (argc != 3) {
 		usage();
 	}
 	sipx->sipx_network = 0L;
@@ -306,8 +281,7 @@ ipx_del_interface(int argc, char **argv)
 	sipx->sipx_type = frame_types[fti].ft_val;
 
 	s = socket(AF_IPX, SOCK_DGRAM, AF_IPX);
-	if (s < 0)
-	{
+	if (s < 0) {
 		sprintf(errmsg, "%s: socket", progname);
 		perror(errmsg);
 		exit(-1);
@@ -318,8 +292,7 @@ ipx_del_interface(int argc, char **argv)
 	if (result == 0)
 		exit(0);
 
-	switch (errno)
-	{
+	switch (errno) {
 	case EPROTONOSUPPORT:
 		fprintf(stderr, "%s: Invalid frame type (%s).\n",
 			progname, frame_types[fti].ft_name);
@@ -340,8 +313,7 @@ ipx_del_interface(int argc, char **argv)
 	exit(-1);
 }
 
-int
-ipx_check_interface(int argc, char **argv)
+int ipx_check_interface(int argc, char **argv)
 {
 	struct sockaddr_ipx *sipx = (struct sockaddr_ipx *) &id.ifr_addr;
 	int s;
@@ -349,8 +321,7 @@ ipx_check_interface(int argc, char **argv)
 	char errmsg[80];
 	int fti;
 
-	if (argc != 3)
-	{
+	if (argc != 3) {
 		usage();
 	}
 	sipx->sipx_network = 0L;
@@ -361,27 +332,24 @@ ipx_check_interface(int argc, char **argv)
 	sipx->sipx_type = frame_types[fti].ft_val;
 
 	s = socket(AF_IPX, SOCK_DGRAM, AF_IPX);
-	if (s < 0)
-	{
+	if (s < 0) {
 		sprintf(errmsg, "%s: socket", progname);
 		perror(errmsg);
 		exit(-1);
 	}
 	sipx->sipx_family = AF_IPX;
 	result = ioctl(s, SIOCGIFADDR, &id);
-	if (result == 0)
-	{
+	if (result == 0) {
 		printf(
 			      "IPX Address for (%s, %s) is %08lX:%02X%02X%02X%02X%02X%02X.\n",
 			      argv[1], frame_types[fti].ft_name,
-			      htonl(sipx->sipx_network), sipx->sipx_node[0],
+			   htonl(sipx->sipx_network), sipx->sipx_node[0],
 			      sipx->sipx_node[1], sipx->sipx_node[2],
 			      sipx->sipx_node[3], sipx->sipx_node[4],
 			      sipx->sipx_node[5]);
 		exit(0);
 	}
-	switch (errno)
-	{
+	switch (errno) {
 	case EPROTONOSUPPORT:
 		fprintf(stderr, "%s: Invalid frame type (%s).\n",
 			progname, frame_types[fti].ft_name);
@@ -402,34 +370,28 @@ ipx_check_interface(int argc, char **argv)
 	exit(-1);
 }
 
-int
-main(int argc, char **argv)
+int main(int argc, char **argv)
 {
 	int i;
 
 	progname = argv[0];
-	if (argc < 2)
-	{
+	if (argc < 2) {
 		usage();
 		exit(-1);
 	}
-	if (strncasecmp(argv[1], "add", 3) == 0)
-	{
+	if (strncasecmp(argv[1], "add", 3) == 0) {
 		for (i = 1; i < (argc - 1); i++)
 			argv[i] = argv[i + 1];
 		ipx_add_interface(argc - 1, argv);
-	} else if (strncasecmp(argv[1], "delall", 6) == 0)
-	{
+	} else if (strncasecmp(argv[1], "delall", 6) == 0) {
 		for (i = 1; i < (argc - 1); i++)
 			argv[i] = argv[i + 1];
 		ipx_delall_interface(argc - 1, argv);
-	} else if (strncasecmp(argv[1], "del", 3) == 0)
-	{
+	} else if (strncasecmp(argv[1], "del", 3) == 0) {
 		for (i = 1; i < (argc - 1); i++)
 			argv[i] = argv[i + 1];
 		ipx_del_interface(argc - 1, argv);
-	} else if (strncasecmp(argv[1], "check", 5) == 0)
-	{
+	} else if (strncasecmp(argv[1], "check", 5) == 0) {
 		for (i = 1; i < (argc - 1); i++)
 			argv[i] = argv[i + 1];
 		ipx_check_interface(argc - 1, argv);
