@@ -25,8 +25,7 @@
 #include "ncplib.h"
 
 
-struct NCPMountRec
-{
+struct NCPMountRec {
 	char *mountDir;
 	char *server;
 	struct ncp_conn *conn;
@@ -71,8 +70,7 @@ static struct sigaction sTermSig;
 /****************************************************************************
  *
  */
-static void
-usage()
+static void usage()
 {
 	fprintf(stderr, "usage: %s [-V]\n", ProgramName);
 	fprintf(stderr, "       %s [-vn] [-s amt] sourcefile destinationfile|directory\n", ProgramName);
@@ -86,19 +84,17 @@ usage()
  * Return pointer to original string if no "/" in string. (except at end)
  */
 static const char *
-myBaseName(const char *path)
+ myBaseName(const char *path)
 {
 	const char *p;
 
-	for (p = &path[strlen(path)]; p != path; p--)
-	{			/* skip ENDING "/" chars */
+	for (p = &path[strlen(path)]; p != path; p--) {		/* skip ENDING "/" chars */
 		if (*p && *p != '/')
 			break;
 	}
 	if (p == path)
 		return p;
-	for (; p != path || *p == '/'; p--)
-	{
+	for (; p != path || *p == '/'; p--) {
 		if (*p == '/')
 			return ++p;
 	}
@@ -109,7 +105,7 @@ myBaseName(const char *path)
  *
  */
 static const char *
-notDir(const char *path)
+ notDir(const char *path)
 {
 	struct stat buf;
 	static const char *notDirectory = "not a directory";
@@ -124,15 +120,12 @@ notDir(const char *path)
 /****************************************************************************
  *
  */
-static int
-handleOptions(const int argc, char *const argv[])
+static int handleOptions(const int argc, char *const argv[])
 {
 	int opt;
 
-	while ((opt = getopt(argc, argv, "vVns:")) != EOF)
-	{
-		switch (opt)
-		{
+	while ((opt = getopt(argc, argv, "vVns:")) != EOF) {
+		switch (opt) {
 
 		case 'V':	/* Version */
 			optVersion = 1;
@@ -149,8 +142,7 @@ handleOptions(const int argc, char *const argv[])
 		case 's':	/* Nice Factor */
 			optNiceFactorSel = 1;
 			optNiceFactor = atoi(optarg);
-			if (optNiceFactor < 1)
-			{
+			if (optNiceFactor < 1) {
 				fprintf(stderr, "%s: -s option requires positive numeric argument > 0\n",
 					ProgramName);
 				return 1;
@@ -168,22 +160,18 @@ handleOptions(const int argc, char *const argv[])
 /****************************************************************************
  * TODO: if recursive flag last MUST be a directory, even if only 2 args.
  */
-static int
-validateFileArgs(const int argc, char *const argv[])
+static int validateFileArgs(const int argc, char *const argv[])
 {
 	const char *p;
-	if (argc == 0)
-	{
+	if (argc == 0) {
 		fprintf(stderr, "%s: No arguments specified.\n", ProgramName);
 		return 1;
 	}
-	if (argc == 1)
-	{
+	if (argc == 1) {
 		fprintf(stderr, "%s: No destination specified.\n", ProgramName);
 		return 1;
 	}
-	if ((argc > 2) && (p = notDir(argv[argc - 1])))
-	{			/* last arg MUST be dir */
+	if ((argc > 2) && (p = notDir(argv[argc - 1]))) {	/* last arg MUST be dir */
 		fprintf(stderr, "%s: %s: %s\n", ProgramName, argv[argc - 1], p);
 		return 1;
 	}
@@ -194,7 +182,7 @@ validateFileArgs(const int argc, char *const argv[])
  * Duplicate a string.
  */
 char *
-duplicateStr(const char *InStr)
+ duplicateStr(const char *InStr)
 {
 	char *dup;
 	if (!InStr)
@@ -208,38 +196,31 @@ duplicateStr(const char *InStr)
 /****************************************************************************
  * load a table of ncpfs mount points.
  */
-int
-loadMountTable()
+int loadMountTable()
 {
 	FILE *mountedFile;
 	struct mntent *mountEntry = NULL;
 	ncpCount = 0;
-	if ((mountedFile = fopen(MOUNTED, "r")) == NULL)
-	{
+	if ((mountedFile = fopen(MOUNTED, "r")) == NULL) {
 		fprintf(stderr, "ncopy: cannot open %s, %s\n", MOUNTED, strerror(errno));
 		return 1;
 	}
-	while ((mountEntry = getmntent(mountedFile)) != NULL)
-	{
+	while ((mountEntry = getmntent(mountedFile)) != NULL) {
 		if (!strcmp(mountEntry->mnt_type, "ncpfs"))
 			ncpCount++;
 	}
-	if (ncpCount)
-	{
+	if (ncpCount) {
 		NcpMountTable = (struct NCPMountRec *)
 		    malloc(ncpCount * sizeof(struct NCPMountRec));
-		if (!NcpMountTable)
-		{
+		if (!NcpMountTable) {
 			fprintf(stderr, "Out of memory\n");
 			fclose(mountedFile);
 			return 1;
 		}
 		fseek(mountedFile, 0, SEEK_SET);
 		ncpCount = 0;
-		while ((mountEntry = getmntent(mountedFile)) != NULL)
-		{
-			if (!strcmp(mountEntry->mnt_type, "ncpfs"))
-			{
+		while ((mountEntry = getmntent(mountedFile)) != NULL) {
+			if (!strcmp(mountEntry->mnt_type, "ncpfs")) {
 				NcpMountTable[ncpCount].mountDir = duplicateStr(mountEntry->mnt_dir);
 				NcpMountTable[ncpCount].server =
 				    duplicateStr(mountEntry->mnt_fsname);
@@ -255,16 +236,13 @@ loadMountTable()
 /****************************************************************************
  * Releases the table of ncpfs mount points.
  */
-void
-releaseMountTable()
+void releaseMountTable()
 {
 	int loop;
 	if (!ncpCount)
 		return;
-	for (loop = ncpCount; loop; loop--, ncpCount--)
-	{
-		if (NcpMountTable[loop - 1].conn)
-		{
+	for (loop = ncpCount; loop; loop--, ncpCount--) {
+		if (NcpMountTable[loop - 1].conn) {
 			ncp_close(NcpMountTable[loop - 1].conn);
 			NcpMountTable[loop - 1].conn = NULL;
 		}
@@ -279,16 +257,14 @@ releaseMountTable()
  * the file.
  * Returns -1 if the files do not reference the same server.
  */
-int
-ncpIndex(const char *InputFile, const char *OutputFile)
+int ncpIndex(const char *InputFile, const char *OutputFile)
 {
 	int loop;
 	char *mountDir;
 	if (!ncpCount)
 		return -1;
 
-	for (loop = 0; loop < ncpCount; loop++)
-	{
+	for (loop = 0; loop < ncpCount; loop++) {
 		mountDir = NcpMountTable[loop].mountDir;
 		if (!strncmp(mountDir, InputFile, strlen(mountDir)) &&
 		    !strncmp(mountDir, OutputFile, strlen(mountDir)))
@@ -302,46 +278,40 @@ ncpIndex(const char *InputFile, const char *OutputFile)
  * Does a regular buffered file copy.
  * This is used if we cannot use the Netware file copy.
  */
-int
-normalFileCopy(const char *InputFile, const char *OutputFile,
-	       char *Buffer, int BufferSize,
-	       const char *paramInputFile,
-	       const char *paramOutputFile)
+int normalFileCopy(const char *InputFile, const char *OutputFile,
+		   char *Buffer, int BufferSize,
+		   const char *paramInputFile,
+		   const char *paramOutputFile)
 {
 	int fdIn, fdOut;
 	long fileSize, totalSize;
 	struct stat statBuf;
 	fdIn = open(InputFile, O_RDONLY);
-	if (fdIn == -1)
-	{
+	if (fdIn == -1) {
 		fprintf(stderr, "%s: Cannot open %s, %s\n", ProgramName, paramInputFile,
 			strerror(errno));
 		return 1;
 	}
-	if (fstat(fdIn, &statBuf))
-	{
+	if (fstat(fdIn, &statBuf)) {
 		fprintf(stderr, "%s: Cannot stat %s, %s\n", ProgramName, paramInputFile,
 			strerror(errno));
 		close(fdIn);
 		return 1;
 	}
-	if (S_ISDIR(statBuf.st_mode))
-	{
+	if (S_ISDIR(statBuf.st_mode)) {
 		close(fdIn);
 		fprintf(stderr, "%s: %s: omitting directory\n", ProgramName, paramInputFile);
 		return 0;	/* At this point, don't consider this a fatal error */
 	}
 	fdOut = open(OutputFile, O_CREAT | O_TRUNC | O_WRONLY, statBuf.st_mode);
-	if (fdOut == -1)
-	{
+	if (fdOut == -1) {
 		fprintf(stderr, "%s: Cannot create %s, %s\n", ProgramName, paramOutputFile,
 			strerror(errno));
 		close(fdIn);
 		return 1;
 	}
 	fileSize = lseek(fdIn, 0, SEEK_END);
-	if (fileSize < 0)
-	{
+	if (fileSize < 0) {
 		fprintf(stderr, "%s: lseek error on %s, %s\n", ProgramName, paramInputFile,
 			strerror(errno));
 		close(fdOut);
@@ -349,19 +319,16 @@ normalFileCopy(const char *InputFile, const char *OutputFile,
 		return 1;
 	}
 	lseek(fdIn, 0, SEEK_SET);
-	if (optVerbose)
-	{
+	if (optVerbose) {
 		printf("Normal copy: %s -> %s 0%%", paramInputFile, paramOutputFile);
 		fflush(stdout);
 	}
 	totalSize = fileSize;
-	while (fileSize)
-	{
+	while (fileSize) {
 		int currentMove;
 		int writeAmt;
 		currentMove = (fileSize > BufferSize) ? BufferSize : fileSize;
-		if (read(fdIn, Buffer, currentMove) != currentMove)
-		{
+		if (read(fdIn, Buffer, currentMove) != currentMove) {
 			fprintf(stderr, "%s: Error reading %s, %s\n", ProgramName, paramInputFile,
 				strerror(errno));
 			close(fdIn);
@@ -369,15 +336,13 @@ normalFileCopy(const char *InputFile, const char *OutputFile,
 			return 1;
 		}
 		writeAmt = write(fdOut, Buffer, currentMove);
-		if (writeAmt < 0)
-		{
+		if (writeAmt < 0) {
 			fprintf(stderr, "%s: Error writing %s, %s\n", ProgramName, paramOutputFile,
 				strerror(errno));
 			close(fdIn);
 			close(fdOut);
 			return 1;
-		} else if (writeAmt == 0)
-		{
+		} else if (writeAmt == 0) {
 			fprintf(stderr, "%s: Out of space on destination device writing %s\n",
 				ProgramName, OutputFile);
 			close(fdIn);
@@ -385,8 +350,7 @@ normalFileCopy(const char *InputFile, const char *OutputFile,
 			return 1;
 		}
 		fileSize -= currentMove;
-		if (optVerbose)
-		{
+		if (optVerbose) {
 			printf("\rNormal copy: %s -> %s %ld%%", paramInputFile, paramOutputFile, (100 - (fileSize * 100 / totalSize)));
 			fflush(stdout);
 		}
@@ -403,11 +367,10 @@ normalFileCopy(const char *InputFile, const char *OutputFile,
  *  Netware file names need to be all upper case.
  */
 char *
-upString(char *str)
+ upString(char *str)
 {
 	char *alias = str;
-	while (*alias)
-	{
+	while (*alias) {
 		*alias = toupper(*alias);
 		++alias;
 	}
@@ -418,12 +381,10 @@ upString(char *str)
  *  Locates the first occurrance of a single character in the input string.
  *  returns -1 if the character is not found.
  */
-int
-stringPosition(const char *str, char token)
+int stringPosition(const char *str, char token)
 {
 	const char *alias = str;
-	while (*alias)
-	{
+	while (*alias) {
 		if (*alias == token)
 			return alias - str;
 		alias++;
@@ -437,8 +398,7 @@ stringPosition(const char *str, char token)
  *  This will mangle the input "FileString", leaving just the file name
  *  component in it when it is finished.
  */
-int
-getDirHandle(struct ncp_conn *conn, char *FileString, __u8 * NewDirHandle)
+int getDirHandle(struct ncp_conn *conn, char *FileString, __u8 * NewDirHandle)
 {
 	struct nw_info_struct info1, info2;
 	int currentLevel = 0;
@@ -446,25 +406,20 @@ getDirHandle(struct ncp_conn *conn, char *FileString, __u8 * NewDirHandle)
 	struct nw_info_struct *parentInfo = NULL;
 	struct nw_info_struct *currentInfo = NULL;
 
-	while ((k = stringPosition(FileString, '/')) >= 0)
-	{
+	while ((k = stringPosition(FileString, '/')) >= 0) {
 		FileString[k] = 0;
-		if (!currentLevel)
-		{
+		if (!currentLevel) {
 			parentInfo = NULL;
 			currentInfo = &info1;
-		} else if (currentLevel % 2)
-		{
+		} else if (currentLevel % 2) {
 			parentInfo = &info1;
 			currentInfo = &info2;
-		} else
-		{
+		} else {
 			parentInfo = &info2;
 			currentInfo = &info1;
 		}
 		if (ncp_do_lookup(conn, parentInfo, FileString,
-				  currentInfo) != 0)
-		{
+				  currentInfo) != 0) {
 			fprintf(stderr, "%s: Ncp lookup failed on directory %s--%s\n",
 				ProgramName, FileString, strerror(errno));
 			return 1;
@@ -474,8 +429,7 @@ getDirHandle(struct ncp_conn *conn, char *FileString, __u8 * NewDirHandle)
 	}
 
 	if (ncp_alloc_short_dir_handle(conn, currentInfo, NCP_ALLOC_TEMPORARY,
-				       NewDirHandle) != 0)
-	{
+				       NewDirHandle) != 0) {
 		fprintf(stderr, "%s: Ncp alloc dir handle failed--%s\n",
 			ProgramName, strerror(errno));
 		return 1;
@@ -487,11 +441,10 @@ getDirHandle(struct ncp_conn *conn, char *FileString, __u8 * NewDirHandle)
 /****************************************************************************
  *  Interfaces with the ncplib to do the netware copy of the file.
  */
-int
-netwareCopyFile(int ncpMountIndex, const char *sourcefile,
-		const char *destfile,
-		const char *paramInputFile,
-		const char *paramOutputFile)
+int netwareCopyFile(int ncpMountIndex, const char *sourcefile,
+		    const char *destfile,
+		    const char *paramInputFile,
+		    const char *paramOutputFile)
 {
 	__u8 source_dir_handle;
 	__u8 dest_dir_handle;
@@ -512,12 +465,10 @@ netwareCopyFile(int ncpMountIndex, const char *sourcefile,
 
 	/* Establish a connection to a Netware mount point if
 	   one is not already established. */
-	if (!NcpMountTable[ncpMountIndex].conn)
-	{
+	if (!NcpMountTable[ncpMountIndex].conn) {
 		NcpMountTable[ncpMountIndex].conn =
 		    ncp_open_mount(NcpMountTable[ncpMountIndex].mountDir, &err);
-		if (err)
-		{
+		if (err) {
 			com_err(ProgramName, err, "opening ncp connection on mount point %s",
 				NcpMountTable[ncpMountIndex].mountDir);
 			return 2;
@@ -530,8 +481,7 @@ netwareCopyFile(int ncpMountIndex, const char *sourcefile,
 	stroffset = strlen(NcpMountTable[ncpMountIndex].mountDir) + 1;
 	sourceDup = duplicateStr(sourcefile + stroffset);
 	destDup = duplicateStr(destfile + stroffset);
-	if (!sourceDup || !destDup)
-	{
+	if (!sourceDup || !destDup) {
 		fprintf(stderr, "%s: Malloc failed duplicating file names\n",
 			ProgramName);
 		return 2;
@@ -541,16 +491,14 @@ netwareCopyFile(int ncpMountIndex, const char *sourcefile,
 
 	/* Get Handles to the input and output directories */
 	if (getDirHandle(sourceconn, sourceDup, &source_dir_handle) ||
-	    getDirHandle(sourceconn, destDup, &dest_dir_handle))
-	{
+	    getDirHandle(sourceconn, destDup, &dest_dir_handle)) {
 		free(sourceDup);
 		free(destDup);
 		return 1;
 	}
 	/* Open the input and output files. */
 	if (ncp_open_file(sourceconn, source_dir_handle, sourceDup, 0, AR_READ,
-			  &source_file) != 0)
-	{
+			  &source_file) != 0) {
 		fprintf(stderr, "%s: Cannot open %s--%s\n",
 			ProgramName, paramInputFile, strerror(errno));
 		free(sourceDup);
@@ -558,8 +506,7 @@ netwareCopyFile(int ncpMountIndex, const char *sourcefile,
 		return 1;
 	}
 	if (ncp_create_file(sourceconn, dest_dir_handle, destDup,
-			    source_file.file_attributes, &dest_file) != 0)
-	{
+			 source_file.file_attributes, &dest_file) != 0) {
 		fprintf(stderr, "%s: Cannot create %s--%s\n", ProgramName, paramOutputFile,
 			strerror(errno));
 		ncp_close_file(sourceconn, source_file.file_id);
@@ -576,8 +523,7 @@ netwareCopyFile(int ncpMountIndex, const char *sourcefile,
 	free(destDup);
 
 	retValue = 0;
-	if (optVerbose)
-	{
+	if (optVerbose) {
 		printf("NetWare copy: %s -> %s 0%%", paramInputFile, paramOutputFile);
 		fflush(stdout);
 	}
@@ -587,28 +533,24 @@ netwareCopyFile(int ncpMountIndex, const char *sourcefile,
 	sourceOff = 0;
 	retryCount = 0;
 
-	while (amtLeft && retryCount < MaxNcopyRetries)
-	{
+	while (amtLeft && retryCount < MaxNcopyRetries) {
 		int ncopyRetValue;
 		if (amtLeft > CopyBlockSize)
 			thisMove = CopyBlockSize;
 		else
 			thisMove = amtLeft;
 		/* If we are being nice and we've copied enough blocks, go to sleep */
-		if (optNice)
-		{
-			if (BlocksCopied == optNiceFactor)
-			{
+		if (optNice) {
+			if (BlocksCopied == optNiceFactor) {
 				sleep(NiceSleepTime);
 				BlocksCopied = 0;
 			} else
 				++BlocksCopied;
 		}
 		ncopyRetValue = ncp_copy_file(sourceconn, source_file.file_id,
-				      dest_file.file_id, sourceOff, sourceOff,
+				 dest_file.file_id, sourceOff, sourceOff,
 					      thisMove, &amountCopied);
-		if (ncopyRetValue != 0)
-		{
+		if (ncopyRetValue != 0) {
 			/* In my testing this only happens when you run out of space 
 			   on the server.
 			   Netware seems to wait a bit before reporting space recently
@@ -617,8 +559,7 @@ netwareCopyFile(int ncpMountIndex, const char *sourcefile,
 			retryCount++;
 			amountCopied = thisMove = 0;
 		}
-		if (amountCopied != thisMove)
-		{
+		if (amountCopied != thisMove) {
 			fprintf(stderr, "%s: Warning, amountCopied (%u) != thisMove (%u)\n",
 				ProgramName, (unsigned int) amountCopied, (unsigned int) thisMove);
 		}
@@ -628,8 +569,7 @@ netwareCopyFile(int ncpMountIndex, const char *sourcefile,
 #endif
 		amtLeft -= amountCopied;
 		sourceOff += amountCopied;
-		if (optVerbose)
-		{
+		if (optVerbose) {
 			printf("\rNetWare copy: %s -> %s %ld%%", paramInputFile, paramOutputFile,
 			       (100 - (long) ((float) amtLeft / (float) totalSize * 100.0)));
 			if (retryCount)
@@ -641,8 +581,7 @@ netwareCopyFile(int ncpMountIndex, const char *sourcefile,
 		retValue = 1;
 	if (optVerbose)
 		printf("\n");
-	if (ncp_close_file(sourceconn, dest_file.file_id) != 0)
-	{
+	if (ncp_close_file(sourceconn, dest_file.file_id) != 0) {
 		fprintf(stderr, "%s: Close failed for %s\n", ProgramName, paramOutputFile);
 		retValue = 1;
 	}
@@ -651,19 +590,16 @@ netwareCopyFile(int ncpMountIndex, const char *sourcefile,
 	CurrentConn = NULL;
 	CurrentFile = NULL;
 
-	if (ncp_close_file(sourceconn, source_file.file_id) != 0)
-	{
+	if (ncp_close_file(sourceconn, source_file.file_id) != 0) {
 		fprintf(stderr, "%s: Close failed for %s\n", ProgramName, paramInputFile);
 		retValue = 1;
 	}
-	if (ncp_dealloc_dir_handle(sourceconn, dest_dir_handle) != 0)
-	{
+	if (ncp_dealloc_dir_handle(sourceconn, dest_dir_handle) != 0) {
 		fprintf(stderr, "%s: Dealloc dir handle error for %s\n", ProgramName,
 			paramOutputFile);
 		retValue = 1;
 	}
-	if (ncp_dealloc_dir_handle(sourceconn, source_dir_handle) != 0)
-	{
+	if (ncp_dealloc_dir_handle(sourceconn, source_dir_handle) != 0) {
 		fprintf(stderr, "%s: Dealloc dir handle error for %s\n", ProgramName,
 			paramInputFile);
 		retValue = 1;
@@ -676,9 +612,8 @@ netwareCopyFile(int ncpMountIndex, const char *sourcefile,
  *  Decides whether to use the traditional file copy or the netware remote
  *  file copy.
  */
-int
-copyFiles(const char *realsource, const char *realdestination,
-	  const char *paraminputfile, const char *paramoutputfile)
+int copyFiles(const char *realsource, const char *realdestination,
+	      const char *paraminputfile, const char *paramoutputfile)
 {
 	int oldUMask;
 	char fileBuffer[24000];
@@ -688,7 +623,7 @@ copyFiles(const char *realsource, const char *realdestination,
 	printf("Real Source '%s'\n"
 	       "Real Dest   '%s'\n"
 	       "Param Src   '%s'\n"
-	    "Param Dest  '%s'\n", realsource, realdestination, paraminputfile,
+	"Param Dest  '%s'\n", realsource, realdestination, paraminputfile,
 	       paramoutputfile);
 #endif
 
@@ -722,8 +657,7 @@ copyFiles(const char *realsource, const char *realdestination,
  * Is it failure if destination fails?
  * Do we Stay in the loop?
  */
-static int
-copyRealPaths(const char *source, const char *destination)
+static int copyRealPaths(const char *source, const char *destination)
 {
 	char realsource[MAXPATHLEN * 2];
 	char realdestination[MAXPATHLEN * 2];
@@ -731,21 +665,18 @@ copyRealPaths(const char *source, const char *destination)
 	char filePart[MAXPATHLEN + 1];
 	const char *p;
 
-	if (realpath(source, realsource) == 0)
-	{			/* the source must at least exist */
+	if (realpath(source, realsource) == 0) {	/* the source must at least exist */
 		fprintf(stderr, "%s: %s: %s\n",
 			ProgramName, source, strerror(errno));
 		return 1;	/* indicate a "source" problem */
 	}
-	if (realpath(destination, realdestination) == 0)
-	{			/* dest file missing? OK */
+	if (realpath(destination, realdestination) == 0) {	/* dest file missing? OK */
 		strncpy(dirPart, destination, MAXPATHLEN);	/* but "dirpart" must work */
 		dirPart[MAXPATHLEN] = 0;
 		p = myBaseName(dirPart);
 		strcpy(filePart, p);
 		dirPart[p - dirPart] = 0;	/* isolates "directory" part from "file part" */
-		if (realpath(dirPart, realdestination) == 0)
-		{
+		if (realpath(dirPart, realdestination) == 0) {
 			fprintf(stderr, "%s: %s: %s\n",
 				ProgramName, dirPart, strerror(errno));
 			return 2;	/* indicate a "destination" problem */
@@ -770,8 +701,7 @@ copyRealPaths(const char *source, const char *destination)
  * if argc > 2 last parameter is a directory
  * by validateFileArgs()
  */
-static int
-handleFileArgs(int argc, char *const argv[])
+static int handleFileArgs(int argc, char *const argv[])
 {
 	int loop;
 	const char *destination;
@@ -781,12 +711,10 @@ handleFileArgs(int argc, char *const argv[])
 	char destinationfile[MAXPATHLEN * 2];
 
 	destination = argv[argc - 1];	/* get LAST argument */
-	for (loop = 0; loop < (argc - 1); loop++)
-	{			/* all file arguments, but last */
+	for (loop = 0; loop < (argc - 1); loop++) {	/* all file arguments, but last */
 		strncpy(destinationfile, destination, MAXPATHLEN);
 		destinationfile[MAXPATHLEN] = 0;
-		if ((argc > 2) || (!notDir(argv[argc - 1])))
-		{		/* destination is a dir */
+		if ((argc > 2) || (!notDir(argv[argc - 1]))) {	/* destination is a dir */
 			if (*destinationfile != '/' || *(destinationfile + 1))
 				strcat(destinationfile, "/");
 			baseNamePtr = myBaseName(argv[loop]);	/* get the file name */
@@ -803,48 +731,41 @@ handleFileArgs(int argc, char *const argv[])
 /****************************************************************************
  * 
  */
-static void
-handleSignals(int sigNumber)
+static void handleSignals(int sigNumber)
 {
 	/* Ignore Signal Handling while cleaning up */
 
 	/* SIGHUP */
 	sHangupSig.sa_handler = SIG_IGN;
-	if (sigaction(SIGHUP, &sHangupSig, NULL) == -1)
-	{
+	if (sigaction(SIGHUP, &sHangupSig, NULL) == -1) {
 		fprintf(stderr, "%s: Reset to ignore SIGHUP signal failed: %s",
 			ProgramName, strerror(errno));
 	}
 	/* SIGINT */
 	sInterruptSig.sa_handler = SIG_IGN;
-	if (sigaction(SIGINT, &sInterruptSig, NULL) == -1)
-	{
+	if (sigaction(SIGINT, &sInterruptSig, NULL) == -1) {
 		fprintf(stderr, "%s: Reset to ignore SIGINT signal failed: %s",
 			ProgramName, strerror(errno));
 	}
 	/* SIGQUIT */
 	sQuitSig.sa_handler = SIG_IGN;
-	if (sigaction(SIGQUIT, &sQuitSig, NULL) == -1)
-	{
+	if (sigaction(SIGQUIT, &sQuitSig, NULL) == -1) {
 		fprintf(stderr, "%s: Reset to ignore SIGQUIT signal failed: %s",
 			ProgramName, strerror(errno));
 	}
 	/* SIGTERM */
 	sTermSig.sa_handler = SIG_IGN;
-	if (sigaction(SIGTERM, &sTermSig, NULL) == -1)
-	{
+	if (sigaction(SIGTERM, &sTermSig, NULL) == -1) {
 		fprintf(stderr, "%s: Reset to ignore SIGTERM signal failed: %s",
 			ProgramName, strerror(errno));
 	}
 	/* If we don't close the ncp output file, we have to ncpumount and
 	   ncpmount before we can get rid of it.  */
-	if (OutputOpen)
-	{
+	if (OutputOpen) {
 		/*  Issue a warning if we cannot close the file */
 		/*  If an error occurs we probably have to umount/mount to 
 		   remove the file */
-		if (ncp_close_file(CurrentConn, CurrentFile->file_id) != 0)
-		{
+		if (ncp_close_file(CurrentConn, CurrentFile->file_id) != 0) {
 			fprintf(stderr, "%s: unclean close of output file", ProgramName);
 		}
 		OutputOpen = 0;
@@ -855,57 +776,48 @@ handleSignals(int sigNumber)
 /****************************************************************************
  * We'll trap Hangup, Interrupt, Quit or Terminate
  */
-static int
-trapSignals()
+static int trapSignals()
 {
-	if (sigaction(SIGHUP, NULL, &sHangupSig))
-	{			/* init structure fields */
+	if (sigaction(SIGHUP, NULL, &sHangupSig)) {	/* init structure fields */
 		fprintf(stderr, "%s: Get HANGUP signal action failed: %s",
 			ProgramName, strerror(errno));
 		return 1;
 	}
 	sHangupSig.sa_handler = handleSignals;
-	if (sigaction(SIGHUP, &sHangupSig, NULL) == -1)
-	{
+	if (sigaction(SIGHUP, &sHangupSig, NULL) == -1) {
 		fprintf(stderr, "%s: Reset HANGUP signal action failed: %s",
 			ProgramName, strerror(errno));
 		return 1;
 	}
-	if (sigaction(SIGINT, NULL, &sInterruptSig))
-	{			/* init structure fields */
+	if (sigaction(SIGINT, NULL, &sInterruptSig)) {	/* init structure fields */
 		fprintf(stderr, "%s: Get INTERRUPT signal action failed: %s",
 			ProgramName, strerror(errno));
 		return 1;
 	}
 	sInterruptSig.sa_handler = handleSignals;
-	if (sigaction(SIGINT, &sInterruptSig, NULL) == -1)
-	{
+	if (sigaction(SIGINT, &sInterruptSig, NULL) == -1) {
 		fprintf(stderr, "%s: Reset INTERRUPT signal action failed: %s",
 			ProgramName, strerror(errno));
 		return 1;
 	}
-	if (sigaction(SIGQUIT, NULL, &sQuitSig))
-	{			/* init structure fields */
+	if (sigaction(SIGQUIT, NULL, &sQuitSig)) {	/* init structure fields */
 		fprintf(stderr, "%s: Get QUIT signal action failed: %s",
 			ProgramName, strerror(errno));
 		return 1;
 	}
 	sQuitSig.sa_handler = handleSignals;
-	if (sigaction(SIGQUIT, &sQuitSig, NULL) == -1)
-	{
+	if (sigaction(SIGQUIT, &sQuitSig, NULL) == -1) {
 		fprintf(stderr, "%s: Reset QUIT signal action failed: %s",
 			ProgramName, strerror(errno));
 		return 1;
 	}
-	if (sigaction(SIGTERM, NULL, &sTermSig))
-	{			/* init structure fields */
+	if (sigaction(SIGTERM, NULL, &sTermSig)) {	/* init structure fields */
 		fprintf(stderr, "%s: Get TERMINATE signal action failed: %s",
 			ProgramName, strerror(errno));
 		return 1;
 	}
 	sTermSig.sa_handler = handleSignals;
-	if (sigaction(SIGTERM, &sTermSig, NULL) == -1)
-	{
+	if (sigaction(SIGTERM, &sTermSig, NULL) == -1) {
 		fprintf(stderr, "%s: Reset TERMINATE signal action failed: %s",
 			ProgramName, strerror(errno));
 		return 1;
@@ -916,24 +828,20 @@ trapSignals()
 /****************************************************************************
  *
  */
-int
-main(int argc, char *const argv[])
+int main(int argc, char *const argv[])
 {
 	int returnCode;
 	ProgramName = argv[0];
 
-	if (handleOptions(argc, argv))
-	{			/* bad option, missing option parameter */
+	if (handleOptions(argc, argv)) {	/* bad option, missing option parameter */
 		usage();
 		return 1;
 	}
-	if (optVersion)
-	{			/* only option not requiring any arguments */
+	if (optVersion) {	/* only option not requiring any arguments */
 		printf("%s version %s\n", ProgramName, VersionStr);
 		return 0;
 	}
-	if (validateFileArgs(argc - optind, argv + optind))
-	{
+	if (validateFileArgs(argc - optind, argv + optind)) {
 		usage();
 		return 1;
 	}
