@@ -15,15 +15,13 @@
 
 static char *progname;
 
-static void
-usage(void)
+static void usage(void)
 {
 	fprintf(stderr, "usage: %s [options] pattern\n", progname);
 	return;
 }
 
-static void
-help(void)
+static void help(void)
 {
 	printf("\n");
 	printf("usage: %s [options]\n", progname);
@@ -41,8 +39,7 @@ help(void)
 	       "\n");
 }
 
-int
-main(int argc, char **argv)
+int main(int argc, char **argv)
 {
 	struct ncp_conn *conn;
 	struct ncp_bindery_object o;
@@ -58,15 +55,12 @@ main(int argc, char **argv)
 
 	progname = argv[0];
 
-	if ((conn = ncp_initialize(&argc, argv, 1, &err)) == NULL)
-	{
+	if ((conn = ncp_initialize(&argc, argv, 1, &err)) == NULL) {
 		com_err(argv[0], err, "when initializing");
 		return 1;
 	}
-	while ((opt = getopt(argc, argv, "h?vt:o:")) != EOF)
-	{
-		switch (opt)
-		{
+	while ((opt = getopt(argc, argv, "h?vt:o:")) != EOF) {
+		switch (opt) {
 		case 'h':
 		case '?':
 			help();
@@ -86,31 +80,26 @@ main(int argc, char **argv)
 		}
 	}
 
-	if (optind < argc)
-	{
+	if (optind < argc) {
 		usage();
 		exit(1);
 	}
-	for (p = pattern; *p != '\0'; p++)
-	{
+	for (p = pattern; *p != '\0'; p++) {
 		*p = toupper(*p);
 	}
 
 	o.object_id = 0xffffffff;
 
 	while (ncp_scan_bindery_object(conn, o.object_id,
-				       type, pattern, &o) == 0)
-	{
+				       type, pattern, &o) == 0) {
 		found = 1;
-		if (verbose != 0)
-		{
+		if (verbose != 0) {
 			printf("%s %08X %04X %d %02X %d\n",
 			       o.object_name, (unsigned int) o.object_id,
 			       (unsigned int) o.object_type,
 			       o.object_flags, o.object_security,
 			       o.object_has_prop);
-		} else
-		{
+		} else {
 			printf("%s %08X %04X\n",
 			       o.object_name, (unsigned int) o.object_id,
 			       (unsigned int) o.object_type);
