@@ -13,14 +13,12 @@
 
 static char *progname;
 
-static void
-usage(void)
+static void usage(void)
 {
 	fprintf(stderr, "usage: %s [options]\n", progname);
 }
 
-static void
-help(void)
+static void help(void)
 {
 	printf("\n");
 	printf("usage: %s [options]\n", progname);
@@ -38,8 +36,7 @@ help(void)
 	       "\n");
 }
 
-int
-main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
 	struct ncp_conn *conn;
 	char *object_name = NULL;
@@ -54,15 +51,12 @@ main(int argc, char *argv[])
 
 	progname = argv[0];
 
-	if ((conn = ncp_initialize(&argc, argv, 1, &err)) == NULL)
-	{
+	if ((conn = ncp_initialize(&argc, argv, 1, &err)) == NULL) {
 		com_err(argv[0], err, "when initializing");
 		goto finished;
 	}
-	while ((opt = getopt(argc, argv, "h?o:t:v")) != EOF)
-	{
-		switch (opt)
-		{
+	while ((opt = getopt(argc, argv, "h?o:t:v")) != EOF) {
+		switch (opt) {
 		case 'o':
 			object_name = optarg;
 			str_upper(object_name);
@@ -83,14 +77,12 @@ main(int argc, char *argv[])
 		}
 	}
 
-	if (object_type < 0)
-	{
+	if (object_type < 0) {
 		fprintf(stderr, "%s: You must specify an object type\n",
 			argv[0]);
 		goto finished;
 	}
-	if (object_name == NULL)
-	{
+	if (object_name == NULL) {
 		fprintf(stderr, "%s: You must specify an object name\n",
 			argv[0]);
 		goto finished;
@@ -98,16 +90,13 @@ main(int argc, char *argv[])
 	info.search_instance = 0xffffffff;
 
 	while (ncp_scan_property(conn, object_type, object_name,
-				 info.search_instance, "*", &info) == 0)
-	{
-		if (verbose != 0)
-		{
+				 info.search_instance, "*", &info) == 0) {
+		if (verbose != 0) {
 			printf("%s %d %02x %d\n",
 			       info.property_name, info.property_flags,
 			       info.property_security,
 			       info.value_available_flag);
-		} else
-		{
+		} else {
 			printf("%s\n", info.property_name);
 		}
 	}
