@@ -13,14 +13,12 @@
 
 static char *progname;
 
-static void
-usage(void)
+static void usage(void)
 {
 	fprintf(stderr, "usage: %s [options]\n", progname);
 }
 
-static void
-help(void)
+static void help(void)
 {
 	printf("\n");
 	printf("usage: %s [options] file/directory\n", progname);
@@ -40,8 +38,7 @@ help(void)
 	       "\n");
 }
 
-int
-main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
 	struct ncp_conn *conn;
 	char *object_name = NULL;
@@ -55,15 +52,12 @@ main(int argc, char *argv[])
 
 	progname = argv[0];
 
-	if ((conn = ncp_initialize(&argc, argv, 1, &err)) == NULL)
-	{
+	if ((conn = ncp_initialize(&argc, argv, 1, &err)) == NULL) {
 		com_err(argv[0], err, "when initializing");
 		goto finished;
 	}
-	while ((opt = getopt(argc, argv, "h?o:t:r:")) != EOF)
-	{
-		switch (opt)
-		{
+	while ((opt = getopt(argc, argv, "h?o:t:r:")) != EOF) {
+		switch (opt) {
 		case 'o':
 			object_name = optarg;
 			str_upper(object_name);
@@ -84,40 +78,34 @@ main(int argc, char *argv[])
 		}
 	}
 
-	if (object_type < 0)
-	{
+	if (object_type < 0) {
 		fprintf(stderr, "%s: You must specify an object type\n",
 			argv[0]);
 		goto finished;
 	}
-	if (object_name == NULL)
-	{
+	if (object_name == NULL) {
 		fprintf(stderr, "%s: You must specify an object name\n",
 			argv[0]);
 		goto finished;
 	}
-	if (rights < 0)
-	{
+	if (rights < 0) {
 		fprintf(stderr, "%s: You must specify a rights mask\n",
 			progname);
 		goto finished;
 	}
-	if (optind != argc - 1)
-	{
+	if (optind != argc - 1) {
 		fprintf(stderr, "%s: You must specify a directory\n",
 			progname);
 		goto finished;
 	}
 	path = argv[optind];
 
-	if (ncp_get_bindery_object_id(conn, object_type, object_name, &o) != 0)
-	{
+	if (ncp_get_bindery_object_id(conn, object_type, object_name, &o) != 0) {
 		fprintf(stderr, "%s: Could not find object %s\n",
 			progname, object_name);
 		goto finished;
 	}
-	if (ncp_add_trustee(conn, 0, path, o.object_id, rights) != 0)
-	{
+	if (ncp_add_trustee(conn, 0, path, o.object_id, rights) != 0) {
 		fprintf(stderr, "%s: Could not add trustee rights\n", progname);
 		goto finished;
 	}
