@@ -13,14 +13,12 @@
 
 static char *progname;
 
-static void
-usage(void)
+static void usage(void)
 {
 	fprintf(stderr, "usage: %s [options]\n", progname);
 }
 
-static void
-help(void)
+static void help(void)
 {
 	printf("\n");
 	printf("usage: %s [options] file/directory\n", progname);
@@ -31,8 +29,7 @@ help(void)
 	       "\n");
 }
 
-int
-main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
 	struct ncp_conn *conn = NULL;
 	char *path = ".";
@@ -43,10 +40,8 @@ main(int argc, char *argv[])
 
 	progname = argv[0];
 
-	while ((opt = getopt(argc, argv, "h?")) != EOF)
-	{
-		switch (opt)
-		{
+	while ((opt = getopt(argc, argv, "h?")) != EOF) {
+		switch (opt) {
 		case 'h':
 		case '?':
 			help();
@@ -57,25 +52,21 @@ main(int argc, char *argv[])
 		}
 	}
 
-	if (optind > argc)
-	{
+	if (optind > argc) {
 		usage();
 		goto finished;
 	}
-	if (optind == argc - 1)
-	{
+	if (optind == argc - 1) {
 		path = argv[optind];
 	}
-	if ((conn = ncp_open_mount(path, &err)) == NULL)
-	{
+	if ((conn = ncp_open_mount(path, &err)) == NULL) {
 		com_err(argv[0], err, "when initializing");
 		goto finished;
 	}
 	if ((err = ncp_get_eff_directory_rights(conn, 0, 0, 0x8006,
 						conn->i.volume_number,
-						conn->i.directory_id, NULL,
-						&rights)) != 0)
-	{
+					      conn->i.directory_id, NULL,
+						&rights)) != 0) {
 		com_err(argv[0], err, "when finding rights");
 		goto finished;
 	}
@@ -90,36 +81,28 @@ main(int argc, char *argv[])
 	       ((rights & NCP_PERM_SEARCH) != 0) ? 'F' : ' ',
 	       ((rights & NCP_PERM_OWNER) != 0) ? 'A' : ' ');
 
-	if ((rights & NCP_PERM_SUPER) != 0)
-	{
+	if ((rights & NCP_PERM_SUPER) != 0) {
 		printf("(S): You have SUPERVISOR rights\n");
 	}
-	if ((rights & NCP_PERM_READ) != 0)
-	{
+	if ((rights & NCP_PERM_READ) != 0) {
 		printf("(R): You may READ from files\n");
 	}
-	if ((rights & NCP_PERM_WRITE) != 0)
-	{
+	if ((rights & NCP_PERM_WRITE) != 0) {
 		printf("(W): You may WRITE to files\n");
 	}
-	if ((rights & NCP_PERM_CREATE) != 0)
-	{
+	if ((rights & NCP_PERM_CREATE) != 0) {
 		printf("(C): You may CREATE files\n");
 	}
-	if ((rights & NCP_PERM_DELETE) != 0)
-	{
+	if ((rights & NCP_PERM_DELETE) != 0) {
 		printf("(E): You may ERASE files\n");
 	}
-	if ((rights & NCP_PERM_MODIFY) != 0)
-	{
+	if ((rights & NCP_PERM_MODIFY) != 0) {
 		printf("(M): You may MODIFY directory\n");
 	}
-	if ((rights & NCP_PERM_SEARCH) != 0)
-	{
+	if ((rights & NCP_PERM_SEARCH) != 0) {
 		printf("(F): You may SCAN for files\n");
 	}
-	if ((rights & NCP_PERM_OWNER) != 0)
-	{
+	if ((rights & NCP_PERM_OWNER) != 0) {
 		printf("(A): You may change ACCESS control\n");
 	}
 	result = 0;
