@@ -18,8 +18,7 @@
 #include <signal.h>
 #include "ncplib.h"
 
-struct nw_queue
-{
+struct nw_queue {
 	struct ncp_conn *conn;
 
 	char queue_name[NCP_BINDERY_NAME_LEN];
@@ -41,15 +40,13 @@ static int
 static int
  poll_queue(struct nw_queue *q);
 
-static void
-usage(void)
+static void usage(void)
 {
 	fprintf(stderr, "usage: %s [options] file\n", progname);
 	exit(1);
 }
 
-static void
-help(void)
+static void help(void)
 {
 	printf("\n");
 	printf("usage: %s [options]\n", progname);
@@ -72,8 +69,7 @@ help(void)
 #define NCP_BINDERY_PSERVER (0x0007)
 #endif
 
-static void
-terminate_handler()
+static void terminate_handler()
 {
 	signal(SIGTERM, terminate_handler);
 	signal(SIGINT, terminate_handler);
@@ -81,16 +77,13 @@ terminate_handler()
 }
 
 /* Daemon_init is taken from Stevens, Adv. Unix programming */
-static int
-daemon_init(void)
+static int daemon_init(void)
 {
 	pid_t pid;
 
-	if ((pid = fork()) < 0)
-	{
+	if ((pid = fork()) < 0) {
 		return -1;
-	} else if (pid != 0)
-	{
+	} else if (pid != 0) {
 		exit(0);	/* parent vanishes */
 	}
 	/* child process */
@@ -103,8 +96,7 @@ daemon_init(void)
 	return 0;
 }
 
-int
-main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
 	struct ncp_conn *conn;
 	int poll_timeout = 30;
@@ -121,40 +113,32 @@ main(int argc, char *argv[])
 
 	progname = argv[0];
 
-	for (i = 1; i < argc; i += 1)
-	{
+	for (i = 1; i < argc; i += 1) {
 		if ((strcmp(argv[i], "-h") == 0)
-		    || (strcmp(argv[i], "-?") == 0))
-		{
+		    || (strcmp(argv[i], "-?") == 0)) {
 			help();
 			exit(0);
 		}
 	}
 
-	for (i = 1; i < argc; i += 1)
-	{
-		if (strcmp(argv[i], "-d") == 0)
-		{
+	for (i = 1; i < argc; i += 1) {
+		if (strcmp(argv[i], "-d") == 0) {
 			debug = 1;
 			break;
 		}
 	}
 
-	if (debug == 0)
-	{
+	if (debug == 0) {
 		daemon_init();
 		openlog("pserver", LOG_PID, LOG_LPR);
 	}
 	if ((conn = ncp_initialize_as(&argc, argv, 1,
-				      NCP_BINDERY_PSERVER, &err)) == NULL)
-	{
+				   NCP_BINDERY_PSERVER, &err)) == NULL) {
 		com_err(argv[0], err, "when initializing");
 		return 1;
 	}
-	while ((opt = getopt(argc, argv, "q:c:j:t:dh")) != EOF)
-	{
-		switch (opt)
-		{
+	while ((opt = getopt(argc, argv, "q:c:j:t:dh")) != EOF) {
+		switch (opt) {
 		case 'q':
 			queue_name = optarg;
 			break;
@@ -178,20 +162,17 @@ main(int argc, char *argv[])
 		}
 	}
 
-	if (argc != optind)
-	{
+	if (argc != optind) {
 		usage();
 		return -1;
 	}
 	memzero(q);
 
-	if (queue_name == NULL)
-	{
+	if (queue_name == NULL) {
 		fprintf(stderr, "You must specify a queue\n");
 		return 1;
 	}
-	if (init_queue(conn, queue_name, command, &q) != 0)
-	{
+	if (init_queue(conn, queue_name, command, &q) != 0) {
 		perror("Could not init queue");
 		ncp_close(conn);
 		return 1;
@@ -202,15 +183,12 @@ main(int argc, char *argv[])
 	signal(SIGTERM, terminate_handler);
 	signal(SIGINT, terminate_handler);
 
-	while (1)
-	{
+	while (1) {
 		if ((poll_queue(&q) != 0)
-		    && (term_request == 0))
-		{
+		    && (term_request == 0)) {
 			continue;
 		}
-		if (term_request != 0)
-		{
+		if (term_request != 0) {
 			break;
 		}
 		sleep(poll_timeout);
@@ -222,9 +200,8 @@ main(int argc, char *argv[])
 	return 0;
 }
 
-static int
-init_queue(struct ncp_conn *conn, char *queue_name, char *command,
-	   struct nw_queue *q)
+static int init_queue(struct ncp_conn *conn, char *queue_name, char *command,
+		      struct nw_queue *q)
 {
 	struct ncp_bindery_object obj;
 
@@ -234,16 +211,14 @@ init_queue(struct ncp_conn *conn, char *queue_name, char *command,
 	q->command = command;
 
 	if (ncp_get_bindery_object_id(conn, NCP_BINDERY_PQUEUE,
-				      queue_name, &obj) != 0)
-	{
+				      queue_name, &obj) != 0) {
 		fprintf(stderr, "Queue %s not found\n", queue_name);
 		return -1;
 	}
 	q->queue_id = obj.object_id;
 	memcpy(q->queue_name, obj.object_name, sizeof(q->queue_name));
 
-	if (ncp_attach_to_queue(conn, q->queue_id) != 0)
-	{
+	if (ncp_attach_to_queue(conn, q->queue_id) != 0) {
 		fprintf(stderr, "Could not attach to queue %s\n",
 			queue_name);
 		return -1;
@@ -252,18 +227,15 @@ init_queue(struct ncp_conn *conn, char *queue_name, char *command,
 }
 
 
-void
-build_command(struct nw_queue *q, struct queue_job *j,
-	      char *target, int target_size)
+void build_command(struct nw_queue *q, struct queue_job *j,
+		   char *target, int target_size)
 {
 	char *s = q->command;
 	char *target_end = target + target_size;
 
-	void add_string(char *s)
-	{
+	void add_string(char *s) {
 		int len = strlen(s);
-		if (target + len + 1 > target_end)
-		{
+		if (target + len + 1 > target_end) {
 			len = target_end - target - 1;
 		}
 		strncpy(target, s, len);
@@ -273,17 +245,14 @@ build_command(struct nw_queue *q, struct queue_job *j,
 
 	memset(target, 0, target_size);
 
-	while ((*s != 0) && (target < target_end))
-	{
-		if (*s != '%')
-		{
+	while ((*s != 0) && (target < target_end)) {
+		if (*s != '%') {
 			*target = *s;
 			target += 1;
 			s += 1;
 			continue;
 		}
-		switch (*(s + 1))
-		{
+		switch (*(s + 1)) {
 		case '%':
 			*target = '%';
 			target += 1;
@@ -293,11 +262,9 @@ build_command(struct nw_queue *q, struct queue_job *j,
 				struct ncp_bindery_object u;
 				if (ncp_get_bindery_object_name
 				    (q->conn, j->j.ClientObjectID, &u)
-				    == 0)
-				{
+				    == 0) {
 					user = u.object_name;
-				} else
-				{
+				} else {
 					user = "*UNKNOWN USER*";
 				}
 				add_string(user);
@@ -314,31 +281,26 @@ build_command(struct nw_queue *q, struct queue_job *j,
 
 
 
-static int
-poll_queue(struct nw_queue *q)
+static int poll_queue(struct nw_queue *q)
 {
 	struct queue_job job;
 	int fd[2];
 	int pid;
 
 	if (ncp_service_queue_job(q->conn, q->queue_id, q->job_type,
-				  &job) != 0)
-	{
+				  &job) != 0) {
 		/* No job for us */
 		return 0;
 	}
-	if (pipe(fd) < 0)
-	{
+	if (pipe(fd) < 0) {
 		syslog(LOG_ERR, "pipe error: %m");
 		goto fail;
 	}
-	if ((pid = fork()) < 0)
-	{
+	if ((pid = fork()) < 0) {
 		syslog(LOG_ERR, "fork error: %m");
 		goto fail;
 	}
-	if (pid > 0)
-	{
+	if (pid > 0) {
 		/* parent */
 		char buf[1024];
 		size_t result;
@@ -347,33 +309,27 @@ poll_queue(struct nw_queue *q)
 		close(fd[0]);	/* close read end */
 
 		while ((result = ncp_read(q->conn, job.file_handle, offset,
-					  sizeof(buf), buf)) > 0)
-		{
+					  sizeof(buf), buf)) > 0) {
 			offset += result;
-			if (write(fd[1], buf, result) != result)
-			{
+			if (write(fd[1], buf, result) != result) {
 				goto fail;
 			}
 		}
 
 		close(fd[1]);	/* and close write end */
 
-		if (waitpid(pid, NULL, 0) < 0)
-		{
+		if (waitpid(pid, NULL, 0) < 0) {
 			syslog(LOG_ERR, "waitpid: %m\n");
 		}
-	} else
-	{
+	} else {
 		/* child */
 
 		char command[2048];
 
 		close(fd[1]);	/* close write end */
 
-		if (fd[0] != STDIN_FILENO)
-		{
-			if (dup2(fd[0], STDIN_FILENO) != STDIN_FILENO)
-			{
+		if (fd[0] != STDIN_FILENO) {
+			if (dup2(fd[0], STDIN_FILENO) != STDIN_FILENO) {
 				syslog(LOG_ERR, "dup2 error: %m\n");
 				close(fd[0]);
 				exit(1);
