@@ -14,8 +14,7 @@
 #include <string.h>
 #include <ctype.h>
 
-void
-main(int argc, char *argv[])
+void main(int argc, char *argv[])
 {
 	struct ncp_conn *conn;
 	struct ncp_bindery_object obj;
@@ -25,27 +24,22 @@ main(int argc, char *argv[])
 	char *p;
 	long err;
 
-	if (argc > 2)
-	{
+	if (argc > 2) {
 		printf("usage: %s [pattern]\n", argv[0]);
 		exit(1);
 	}
-	if (argc == 2)
-	{
+	if (argc == 2) {
 		pattern = argv[1];
 	}
-	for (p = pattern; *p != '\0'; p++)
-	{
+	for (p = pattern; *p != '\0'; p++) {
 		*p = toupper(*p);
 	}
 
-	if ((conn = ncp_open(NULL, &err)) == NULL)
-	{
+	if ((conn = ncp_open(NULL, &err)) == NULL) {
 		com_err(argv[0], err, "in ncp_open");
 		exit(1);
 	}
-	if (isatty(1))
-	{
+	if (isatty(1)) {
 		printf("\n%-52s%-10s%-12s\n"
 		       "-----------------------------------------------"
 		       "---------------------------\n",
@@ -57,8 +51,7 @@ main(int argc, char *argv[])
 
 	while (ncp_scan_bindery_object(conn, obj.object_id,
 				       NCP_BINDERY_FSERVER, pattern,
-				       &obj) == 0)
-	{
+				       &obj) == 0) {
 		struct nw_property prop;
 		struct prop_net_address *naddr
 		= (struct prop_net_address *) &prop;
@@ -68,9 +61,8 @@ main(int argc, char *argv[])
 		printf("%-52s", obj.object_name);
 
 		if (ncp_read_property_value(conn, NCP_BINDERY_FSERVER,
-					    obj.object_name, 1, "NET_ADDRESS",
-					    &prop) == 0)
-		{
+				       obj.object_name, 1, "NET_ADDRESS",
+					    &prop) == 0) {
 			ipx_print_network(naddr->network);
 			printf("  ");
 			ipx_print_node(naddr->node);
@@ -78,8 +70,7 @@ main(int argc, char *argv[])
 		printf("\n");
 	}
 
-	if ((found == 0) && (isatty(1)))
-	{
+	if ((found == 0) && (isatty(1))) {
 		printf("No servers found\n");
 	}
 	ncp_close(conn);
